@@ -16,7 +16,8 @@ use Text::ParseWords qw( shellwords );
 # distributed with Alien-Build.
 
 # ABSTRACT: Compiler and linker wrapper for Alien
-our $VERSION = '1.00'; # VERSION
+our $VERSION = '1.03_01'; # TRIAL VERSION
+$VERSION = eval $VERSION;
 
 
 my @cflags_I;
@@ -93,6 +94,7 @@ sub import
     if($alien eq '!export')
     {
       $export = 0;
+      next;
     }
     $alien = "Alien::$alien" unless $alien =~ /::/;
     my $alien_pm = $alien . '.pm';
@@ -169,7 +171,7 @@ Alien::Base::Wrapper - Compiler and linker wrapper for Alien
 
 =head1 VERSION
 
-version 1.00
+version 1.03_01
 
 =head1 SYNOPSIS
 
