@@ -8,12 +8,13 @@ use Capture::Tiny qw( capture );
 use Carp ();
 
 # ABSTRACT: Alien::Build installer code for ExtUtils::MakeMaker
-our $VERSION = '1.00'; # VERSION
+our $VERSION = '1.03_01'; # TRIAL VERSION
+$VERSION = eval $VERSION;
 
 
 sub new
 {
-  my($class) = @_;
+  my($class, %prop) = @_;
   
   my $self = bless {}, $class;
   
@@ -24,6 +25,15 @@ sub new
     )
   ;
   
+  if(defined $prop{alienfile_meta})
+  {
+    $self->{alienfile_meta} = $prop{alienfile_meta};
+  }
+  else
+  {
+    $self->{alienfile_meta} = 1;
+  }
+  
   $self->build->load_requires('configure');
   $self->build->root;
   $self->build->checkpoint;
@@ -38,6 +48,12 @@ sub build
 }
 
 
+sub alienfile_meta
+{
+  shift->{alienfile_meta};
+}
+
+
 sub mm_args
 {
   my($self, %args) = @_;
@@ -110,6 +126,20 @@ sub mm_args
   #$args{META_MERGE}->{'meta-spec'}->{version} = 2;
   $args{META_MERGE}->{dynamic_config} = 1;
   
+  if($self->alienfile_meta)
+  {
+    $args{META_MERGE}->{x_alienfile} = {
+      generated_by => "@{[ __PACKAGE__ ]} version @{[ __PACKAGE__->VERSION || 'dev' ]}",
+      requires => {
+        map {
+          my %reqs = %{ $self->build->requires($_) };
+          $reqs{$_} = "$reqs{$_}" for keys %reqs;
+          $_ => \%reqs;
+        } qw( share system )
+      },
+    };
+  }
+  
   $self->build->checkpoint;
   %args;
 }
@@ -304,7 +334,7 @@ Alien::Build::MM - Alien::Build installer code for ExtUtils::MakeMaker
 
 =head1 VERSION
 
-version 1.00
+version 1.03_01
 
 =head1 SYNOPSIS
 
@@ -353,6 +383,12 @@ Create a new instance of L<Alien::Build::MM>.
 
 The L<Alien::Build> instance.
 
+=head2 alienfile_meta
+
+ my $bool = $abmm->alienfile_meta
+
+Set to a false value, in order to turn off the x_alienfile meta
+
 =head1 METHODS
 
 =head2 mm_args
