@@ -5,7 +5,8 @@ use warnings;
 use Alien::Build::Plugin;
 
 # ABSTRACT: Extraction negotiation plugin
-our $VERSION = '1.00'; # VERSION
+our $VERSION = '1.03_01'; # TRIAL VERSION
+$VERSION = eval $VERSION;
 
 
 has '+format' => 'tar';
@@ -65,7 +66,7 @@ sub _pick
     # if we don't have Archive::Zip, check if we have the unzip command
     elsif(eval { require Alien::Build::Plugin::Extract::CommandLine; Alien::Build::Plugin::Extract::CommandLine->new->unzip_cmd })
     {
-      return 'Extract::CommandLine';
+      return 'CommandLine';
     }
     
     # okay fine.  I will try to install Archive::Zip :(
@@ -112,7 +113,7 @@ Alien::Build::Plugin::Extract::Negotiate - Extraction negotiation plugin
 
 =head1 VERSION
 
-version 1.00
+version 1.03_01
 
 =head1 SYNOPSIS
 
